module.exports = defineTest({
	description: 'uses the correct "this" value in class properties'
});
